import { getAccountList, getCash } from '@/api/assets'
import { getStorage, delStorage } from "@/utils/localStorage";
import WebSocketClient from "@/utils/socket";
import bus from '@/utils/bus'
import { getCurrencyList } from "@/api/product";
export default {
  data () {
    return {
      getAccountListSign: false,
      getCashInfoSign: false,
      updateTradeAssetSocket: null,
      sendTimer: null,
    }
  },
  beforeDestroy () {
    bus.$off('updateAssets', this.updateAssets)
  },
  watch: {
    isLogin(val) {
      if (!val) {
        this.updateTradeAssetSocket && this.updateTradeAssetSocket.close()
        clearInterval(this.sendTimer)
        return
      }
      this.creatSocket1(getStorage('userToken') || Math.random())
    }
  },
  created () {
    bus.$on('updateAssets', this.updateAssets)
    this.creatSocket1(getStorage('userToken') || Math.random())
    this.getCurrencyList()
  },
  methods: {
    creatSocket1(token) {
      this.updateTradeAssetSocket = new WebSocketClient('/Transaction/' + token)
      this.updateTradeAssetSocket.connect(this.onopen1, this.onmessage1)
    },
    onopen1() {
      this.sendTimer = setInterval(() => {
        this.updateTradeAssetSocket.send({heart: 12})
      }, 40000)
    },
    onmessage1(msg) {
      let data = JSON.parse(msg.data)
      if (data) {
        if (data.type === "trades") {
          bus.$emit('updateOrder')
          if (data.action == '1') {
            bus.$emit('updateCloseOrder')
          }
          this.getAccountList()
        }
        if (data.action === "withdrawCash") {
          this.getCash()
        }
        if (data.action === "logoutUser" || data.action === "updateLoginPassword") {
          this.$notify({
            // message: '网络故障需要重新登录',
            message: data.action === "logoutUser" ? this.$t('ajax.l4') : this.$t('ajax.l2'),
            type: 'danger'
          });
          delStorage('userToken')
          this.$store.commit('SET_LOGIN', false)
          this.$store.commit('SET_USER_INFO', {})
          bus.$emit('socketInit')
          this.$router.push('/login')
        }
        if (data.action === "depositCash" || data.action === 'TransactionToCash' || data.action === 'CashToTransaction') {
          this.getCash()
          this.getAccountList()
        }
      }
    },
    // 获取储蓄帐号列表
    getAccountList() {
      if (this.getAccountListSign) {
        return
      }
      this.getAccountListSign = true
      getAccountList().then((res) => {
        let list = (res.list || []).filter(item => item.server == 'CFD')
        this.$store.commit('setAccountList',list)
      }).finally(() => {
        this.getAccountListSign = false
      }).catch(() => {})
    },
    // 获取储蓄帐号列表
    getCash() {
      if (this.getCashInfoSign) {
        return
      }
      this.getCashInfoSign = true
      getCash().then((res) => {
        let cashInfo = res || []
        this.$store.commit('setCashInfo', cashInfo)
      }).finally(() => {
        this.getCashInfoSign = false
      }).catch(() => {})
    },
    getCurrencyList() {
      getCurrencyList({
        type: 1
      }).then(res => {
        let list = res.list || []
        let obj = {
          'USD': 1,
          'CNY': 1,
          'HKD': 1,
        }
        list.forEach(item => {
          if (obj[item.symbol]) {
            obj[item.symbol] = item.rate
          }
        })
        this.$store.commit('setCurrencyList', obj)
      }).catch(() => {
        
      })
    },
    updateAssets(list) {
      if (!this.isLogin) {
        return
      }
      if (this.updateTradeAssetSocket && this.updateTradeAssetSocket.socket.readyState == 3) {
        this.sendTimer && clearInterval(this.sendTimer)
        this.creatSocket1(getStorage('userToken') || Math.random())
      }
      if (list) {
        list.forEach(item => {
          this[item]()
        })
      }
    }
  }
}